# AqOrg

Estimate the thermodynamic properties and HKF parameters of aqueous organic molecules using second order group additivity methods.

## Features

Placeholder

## Requirements

This package must be installed into an environment with [RDKit](https://www.rdkit.org/). See [these instructions](https://github.com/rdkit/rdkit/blob/master/Docs/Book/Install.md) for installing RDKit.

## Installation

Activate the environment containing RDKit. Then install `AqOrg` with pip:

```
$ pip install AqOrg
```

## Usage

Placeholder